Django Gears
============

.. image:: https://secure.travis-ci.org/gears/django-gears.png?branch=develop

Gears_ for Django_.

.. _Gears: https://github.com/gears/gears
.. _Django: https://www.djangoproject.com/
